==> freemedforms-project_0.7.6.orig.tar.gz: freemedforms-0.7.6/global_resources/translations/pmhplugin_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es_ES">
<context>
    <name>PMH</name>
    <message>
        <location filename="../../plugins/pmhplugin/constants.h" line="143"/>
        <source>New past medical history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/constants.h" line="144"/>
        <source>Remove past medical history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/constants.h" line="145"/>
        <source>Create a new category</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/constants.h" line="146"/>
        <source>Remove category</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/constants.h" line="147"/>
        <source>Past medical history category manager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/constants.h" line="149"/>
        <source>Not defined</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/constants.h" line="150"/>
        <source>Chronic disease</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/constants.h" line="151"/>
        <source>Chronic disease without acute episode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/constants.h" line="152"/>
        <source>Acute disease</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/constants.h" line="153"/>
        <source>Risk factor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/constants.h" line="155"/>
        <source>Active</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/constants.h" line="156"/>
        <source>In remission</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/constants.h" line="157"/>
        <source>Quiescent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/constants.h" line="158"/>
        <source>Cured</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PMH::Internal::PmhModeWidget</name>
    <message>
        <location filename="../../plugins/pmhplugin/pmhmodewidget.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/pmhmode.cpp" line="294"/>
        <source>Remove PMHx</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/pmhmode.cpp" line="295"/>
        <source>Do you really want to remove the PMHx called &lt;br /&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&lt;b&gt;%1&lt;/b&gt;?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PMH::Internal::PmhPreferencesWidget</name>
    <message>
        <location filename="../../plugins/pmhplugin/pmhpreferencespage.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/pmhpreferencespage.ui" line="20"/>
        <source>Data saving</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/pmhpreferencespage.ui" line="26"/>
        <source>Always ask for confirmation before deletion</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/pmhpreferencespage.ui" line="36"/>
        <source>Colors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/pmhpreferencespage.ui" line="42"/>
        <location filename="../../plugins/pmhplugin/pmhpreferencespage.ui" line="61"/>
        <source>Category background color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/pmhpreferencespage.ui" line="71"/>
        <location filename="../../plugins/pmhplugin/pmhpreferencespage.ui" line="90"/>
        <source>Category foreground color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/pmhpreferencespage.ui" line="100"/>
        <location filename="../../plugins/pmhplugin/pmhpreferencespage.ui" line="103"/>
        <source>PMHx background color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/pmhpreferencespage.ui" line="129"/>
        <location filename="../../plugins/pmhplugin/pmhpreferencespage.ui" line="148"/>
        <source>PMHx foreground color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/pmhpreferencespage.ui" line="161"/>
        <source>Fonts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/pmhpreferencespage.ui" line="167"/>
        <source>Category font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/pmhpreferencespage.ui" line="174"/>
        <location filename="../../plugins/pmhplugin/pmhpreferencespage.ui" line="188"/>
        <source>Change...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/pmhpreferencespage.ui" line="181"/>
        <source>PMHx font</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PMH::Internal::PmhViewer</name>
    <message>
        <location filename="../../plugins/pmhplugin/pmhviewer.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/pmhviewer.ui" line="29"/>
        <source>Past Medical History</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/pmhviewer.ui" line="222"/>
        <source>Patient</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/pmhviewer.ui" line="46"/>
        <location filename="../../plugins/pmhplugin/pmhviewer.ui" line="189"/>
        <source>General information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/pmhviewer.ui" line="52"/>
        <source>Personal label</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/pmhviewer.ui" line="62"/>
        <source>Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/pmhviewer.ui" line="72"/>
        <source>Status</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/pmhviewer.ui" line="82"/>
        <source>Confidence index</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/pmhviewer.ui" line="111"/>
        <source>Privacy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/pmhviewer.ui" line="118"/>
        <source>Make this PMHx private</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/pmhviewer.ui" line="170"/>
        <source>Category</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/pmhviewer.ui" line="195"/>
        <source>Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/pmhviewer.ui" line="209"/>
        <source>Manage ICD10 Codes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/pmhviewer.ui" line="132"/>
        <source>Episodes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/pmhviewer.ui" line="157"/>
        <source>Comment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/pmhviewer.ui" line="142"/>
        <source>Management</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/pmhviewer.ui" line="147"/>
        <source>Contacts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/pmhviewer.ui" line="152"/>
        <source>Links</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PMH::PmhCategoryModel</name>
    <message>
        <location filename="../../plugins/pmhplugin/pmhcategorymodel.cpp" line="1224"/>
        <location filename="../../plugins/pmhplugin/pmhcategorymodel.cpp" line="1234"/>
        <source>Patient PMHx synthesis</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PMH::PmhCreatorDialog</name>
    <message>
        <location filename="../../plugins/pmhplugin/pmhcreatordialog.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/pmhcreatordialog.cpp" line="55"/>
        <source>Past Medical History Creator</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PMH::PmhEpisodeModel</name>
    <message>
        <location filename="../../plugins/pmhplugin/pmhepisodemodel.cpp" line="264"/>
        <source>Starting date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/pmhepisodemodel.cpp" line="265"/>
        <source>Ending date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/pmhepisodemodel.cpp" line="266"/>
        <source>Label</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/pmhplugin/pmhepisodemodel.cpp" line="267"/>
        <source>ICD10 coding</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PMH::PmhEpisodeViewer</name>
    <message>
        <location filename="../../plugins/pmhplugin/pmhepisodeviewer.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PMH::PmhPlugin</name>
    <message>
        <location filename="../../plugins/pmhplugin/pmhplugin.cpp" line="84"/>
        <location filename="../../plugins/pmhplugin/pmhplugin.cpp" line="100"/>
        <source>Initializing PMHx database plugin...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PMH::PmhViewer</name>
    <message>
        <location filename="../../plugins/pmhplugin/pmhviewer.cpp" line="267"/>
        <source>Replacing pmh data</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> freemedforms-project_0.8.0.orig.tar.gz: freemedforms-0.8.0/global_resources/translations/pmhplugin_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es_ES">
<context>
    <name>PMH</name>
    <message>
        <source>New past medical history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove past medical history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Create a new category</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove category</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Past medical history category manager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Not defined</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Chronic disease</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Chronic disease without acute episode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Acute disease</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Risk factor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Active</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>In remission</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Quiescent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cured</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PMH::Internal::PmhModeWidget</name>
    <message>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove PMHx</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do you really want to remove the PMHx called &lt;br /&gt;&amp;nbsp;&amp;nbsp;&amp;nbsp;&lt;b&gt;%1&lt;/b&gt;?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PMH::Internal::PmhPlugin</name>
    <message>
        <source>Initializing PMHx database plugin...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PMH::Internal::PmhPreferencesWidget</name>
    <message>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Data saving</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Always ask for confirmation before deletion</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Colors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Category background color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Category foreground color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PMHx background color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PMHx foreground color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fonts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Category font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Change...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PMHx font</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PMH::Internal::PmhViewer</name>
    <message>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Past Medical History</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>General information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Personal label</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Status</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Confidence index</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Privacy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Make this PMHx private</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Episodes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Management</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Contacts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Links</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Comment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Category</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Manage ICD10 Codes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Patient</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PMH::PmhCategoryModel</name>
    <message>
        <source>Patient PMHx synthesis</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PMH::PmhCreatorDialog</name>
    <message>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Past Medical History Creator</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PMH::PmhEpisodeModel</name>
    <message>
        <source>Starting date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ending date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ICD10 coding</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PMH::PmhEpisodeViewer</name>
    <message>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PMH::PmhViewer</name>
    <message>
        <source>Replacing pmh data</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
